@@ -23,7 +23,7 @@ PUBLIC_FOLDER = os.path.join("./", "temp", "public")
 
 @aidserver.route("/", methods=["GET"])
 async def ping():
-    return await json_resp({"status": "OK"}, status=200)
+    return "It works!"
 
 
 @aidserver.route("/infer", methods=["GET", "POST"])
